"""
    Data Modelling Storage Service

    API for basic data modelling interaction  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import dmss_api
from dmss_api.model.repository import Repository
globals()['Repository'] = Repository
from dmss_api.model.data_source_request import DataSourceRequest


class TestDataSourceRequest(unittest.TestCase):
    """DataSourceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDataSourceRequest(self):
        """Test DataSourceRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DataSourceRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
